@@ -104,23 +104,6 @@ gboolean creporter_cp_execute_restart()
 	return TRUE;
 }
 
-/**
-  This function is used to check if the Crash Reporter Daemon is running
-
-  @param void
-  @return gboolean - TRUE if the daemon is running, else FALSE
-  */
-static gboolean 
-is_running(const gchar * cmd)
-{
-	if(system(cmd) == 0) {
-		osso_log(LOG_DEBUG, "[%s]: checked [%s], running", __FUNCTION__, cmd);
-		return TRUE;
-	}
-	osso_log(LOG_DEBUG, "[%s]: checked [%s], not running", __FUNCTION__, cmd);
-	return FALSE;
-}
-
 /** 
   This function will remove a 'core-dumps' directory with contents
 
@@ -247,7 +230,7 @@ creporter_create_dialog_widgets(creporterData *data,
 				 privsett->sending_enabled);
 
     data->caption_sending_enabled =
-	hildon_caption_new(size_group, _("Notify about new crash reports"),
+	hildon_caption_new(size_group, _("Upload crash reports"),
 			   data->checkbox_sending_enabled, NULL, 
 			   HILDON_CAPTION_OPTIONAL);
     gtk_box_pack_start(GTK_BOX(vbox), data->caption_sending_enabled, 
@@ -262,7 +245,7 @@ creporter_create_dialog_widgets(creporterData *data,
 				 privsett->avoid_dups);
 
     data->caption_avoid_dups =
-	hildon_caption_new(size_group, _("Auto-delete repeating duplicates"),
+	hildon_caption_new(size_group, _("Auto-delete duplicates"),
 			   data->checkbox_avoid_dups, NULL, 
 			   HILDON_CAPTION_OPTIONAL);
     gtk_box_pack_start(GTK_BOX(vbox), data->caption_avoid_dups, 
@@ -389,6 +372,7 @@ creporter_cp_dialog_create(gpointer window, osso_context_t *context)
 {
     GtkWidget *settings_dialog = NULL;
     GtkWidget *privacy_stmt = NULL;
+    GtkWidget *manage_stmt = NULL;
     creporterData *dialog_data = NULL;
     gboolean validate = FALSE;
     gboolean ret = FALSE;
@@ -444,9 +428,9 @@ creporter_cp_dialog_create(gpointer window, osso_context_t *context)
 				   "wdgt_bd_save"),
 			  CP_RESPONSE_OK);
 
-    if (!is_running("pidof " CRASH_REPORTER_UI)) {
-	gtk_dialog_add_button(GTK_DIALOG(settings_dialog),
-			      _("Send all"),
+    if (!run_system_cmd("pidof " CRASH_REPORTER_UI)) {
+	manage_stmt = gtk_dialog_add_button(GTK_DIALOG(settings_dialog),
+			      _("Reports"),
 			      CP_RESPONSE_SEND_ALL);
     }
 
