@@ -53,6 +53,8 @@ gboolean avoid_dups = TRUE;
 #define PID_FILE "/tmp/creporter.pid"
 #define AFTERBOOT_WAIT (30)
 
+void lifelog_add_event(char *event, char *datastr);
+
 /*
  * (re-)activate directory monitoring.
  */
@@ -88,7 +90,18 @@ hw_state_event_cb(osso_hw_state_t *hw_state, gpointer data)
 {
 	if (hw_state->shutdown_ind == TRUE) {
 		sending_enabled = 0;
-		osso_log(LOG_DEBUG, "[%s]: Shutting down\n", __FUNCTION__);
+		osso_log(LOG_DEBUG, "[%s]:Shutting down", __FUNCTION__);
+		/*
+		 * There is possibility that daemon sends RPC about new rcore
+		 * to UI, which goes processing (and remains in rpc call)
+		 * and shortly after that system shuts down.
+		 * Both daemon and UI are sent shutdown signal (daemon processes own here)
+		 * but UI is not processing it because its whole UI part is run
+		 * from that previous rpc call.
+		 * UI will crash later in gdk_x_error because X is going/gone away.
+		 * We reduce that risk by trying to kill UI from here.
+		 */
+		run_system_cmd("/usr/bin/killall " CRASH_REPORTER_UI);
 		g_main_loop_quit((GMainLoop *)data);
 		return;
 	}
@@ -162,8 +175,7 @@ mmc_change_tmo_handler(void * context)
 
 /*
  * real values for normal use
- *
-*/
+ */
 #define LIFELOG_TICK 3600
 #define LIFELOG_SEND_CYCLE 3600*24
 
@@ -184,8 +196,9 @@ echo LL_ID_CELL imei=`dbus-send --system --print-reply --dest=com.nokia.csd.Info
 imsi=`dbus-send --system --print-reply --dest=com.nokia.phone.SSC /com/nokia/phone/SSC com.nokia.phone.SSC.get_imsi | tail -n +2 | awk '{print $2}'`,\
 cellmosw=`dbus-send --system --print-reply --dest=com.nokia.csd.Info /com/nokia/csd/info com.nokia.csd.Info.GetMCUSWVersion | tail -n +2`,"
 
+#define LL_TICK_S "LL_TICK"
 #define LIFELOG_TICK_ENTRY_CMD 	"\
-echo LL_TICK date=`date +%s`,\
+echo " LL_TICK_S " date=`date +%s`,\
 `lshal | awk '/battery.charge_level.percentage/{print \"batt_perc=\" $3} \
               /battery.rechargeable.is_charging/{print \", charging=\" $3}'`,\
 uptime=`cat /proc/uptime`,\
@@ -209,7 +222,9 @@ call-counters=`echo 'select * from Events where Events.service_id = 1;' | sqlite
 
 //static gboolean lifelog_timer_handler(void * context);
 static gint lifelog_timer_id = 0;
+#ifndef RUNS_IN_SDK_HOST
 static ConIcConnection *connection = NULL;
+#endif
 static int lifelog_send_countdown = LIFELOG_SEND_CYCLE;
 static gboolean can_send = FALSE, want_send = FALSE;
 static gchar * lifelog_file_name_base = NULL; 
@@ -219,7 +234,7 @@ static void
 lifelog_start_new_file()
 {
     int rv;
-    osso_log(LOG_DEBUG, "[%s]: start new file", __FUNCTION__);
+    osso_log(LOG_DEBUG, "start new file");
 
     rv = system(LIFELOG_STATIC_ENTRY_GEN_CMD ">" LIFELOG_FILE);
     rv = system(LIFELOG_STATIC_ENTRY_CELL_CMD ">>" LIFELOG_FILE);
@@ -258,15 +273,20 @@ lifelog_do_send(gchar * file)
 
     sprintf(cmd, "%s -c %s > %s", LZOP_PROG, file, fname);
     rv = system(cmd);
-    osso_log(LOG_DEBUG, "[%s]:rv=%d from cmd=[%s]", __FUNCTION__, rv, cmd);
+    /*osso_log(LOG_DEBUG, "[%s]:rv=%d from cmd=[%s]", __FUNCTION__, rv, cmd);*/
 
-    sprintf(cmd, "nice /usr/bin/crash_reporter_ui %s >/dev/null 2>/dev/null", fname);
+    sprintf(cmd, "nice /usr/bin/%s %s >/dev/null 2>/dev/null", CRASH_REPORTER_UI, fname);
     rv = system(cmd);
     osso_log(LOG_DEBUG, "[%s]: rv=%d from cmd[%s]", 
 	     __FUNCTION__, rv, cmd);
 
-    if(!rv) {
-	unlink(fname);
+    /* remove lzo file regardless of sending status because we do
+     * nothing with that file later anyway and it will remain garbage in /tmp
+     * in (rare) cases where sending fails at that point
+     */
+    unlink(fname);
+    if (rv == 0) {
+	unlink(file);
     }
     return rv;
 }
@@ -307,9 +327,6 @@ lifelog_try_send(void *context)
 static void
 lifelog_schedule_try_send()
 {
-    osso_log(LOG_DEBUG, "[%s]: can_send=%d want_send=%d",
-	     __FUNCTION__, can_send, want_send);
-
     if (lifelog_send_tmo_id) {
 	g_source_remove(lifelog_send_tmo_id);
     }
@@ -339,6 +356,21 @@ lifelog_timer_handler (void * context)
     return TRUE; /* timer keeps running */
 }
 
+void 
+lifelog_add_event(char *event, char *datastr)
+{
+    char cmd[512];
+    int rv;
+
+    sprintf(cmd, "echo LL_%s date=`date +%%s`, %s >> %s", event, datastr, LIFELOG_FILE);
+    rv = system(cmd);
+    /*
+    osso_log(LOG_DEBUG, "[%s]: rv=%d from cmd[%s]", 
+	     __FUNCTION__, rv, cmd);
+    */
+}
+
+#ifndef RUNS_IN_SDK_HOST
 /*
  * Here we learn about "connected or not" state
  * If getting connected, and something to send,
@@ -353,8 +385,6 @@ lifelog_connection_cb(ConIcConnection * connection,
 
     switch (status) {
     case CON_IC_STATUS_CONNECTED:
-	osso_log(LOG_DEBUG, "[%s]: Event CON_IC_STATUS_CONNECTED", 
-		 __FUNCTION__);
 	can_send = TRUE;
 	if (want_send) {
 	    lifelog_schedule_try_send();
@@ -362,17 +392,14 @@ lifelog_connection_cb(ConIcConnection * connection,
 	break;
 
     case CON_IC_STATUS_DISCONNECTED:
-	osso_log(LOG_DEBUG, "[%s]: Event CON_IC_STATUS_DISCONNECTED",
-		 __FUNCTION__);
 	can_send = FALSE;
 	break;
 
     default:
-	osso_log(LOG_DEBUG, "[%s]: Event status %d is not handled", 
-		 __FUNCTION__, status);
 	break;
     }
 }
+#endif
 
 /*
  * some preparation
@@ -435,62 +462,52 @@ lifelog_check_existing_file ()
 {
     int rv;
     gsize len;
-    GError *err = NULL;
     gchar *curlog = NULL;
     gchar *p, *pend;
-    gint records = 0;
+    gint records;
 
     rv = g_file_get_contents(LIFELOG_FILE,
 			     &curlog,
 			     &len,
-			     &err);
-    if (err) {
-	/*	osso_log(LOG_DEBUG, "[%s]:gerror:%s", __FUNCTION__, err->message);*/
-	g_error_free(err);
-    }
+			     NULL);
     if(!rv) {
-	/*	osso_log(LOG_DEBUG, "[%s]:can not read current log file %s", __FUNCTION__, LIFELOG_FILE);*/
 	lifelog_start_new_file();
     } else {
 	if(g_strstr_len(curlog, len, lifelog_swrel)) {
-	    osso_log(LOG_DEBUG, "[%s]:current swver[%s] found in existing file, will continue it", 
-		     __FUNCTION__, lifelog_swrel);
+	    osso_log(LOG_DEBUG, "current ver[%s] file exists, will continue",
+		     lifelog_swrel);
 	    /*
-	     * count the lines
+	     * count the lines with LL_TICK hdr
 	     */
+	    p = curlog;
 	    pend = curlog + len;
-	    for (p = curlog ; p && *p && (p < pend); p++) {
-		if (*p == '\n') {
+	    for (records = 0; (p < pend) && *p; p++) {
+	      if ((*p == '\n') 
+		  && (p + strlen(LL_TICK_S) + 4 < pend) 
+		  && (g_strstr_len(p, strlen(LL_TICK_S) + 4, LL_TICK_S))) {
 		    records += 1;
 		}
 	    }
-	    /*
-	     * We have 2 lines header and 2 lines per record.
-	     * XXX note that this code has 2,2 hard coded and needs to be changed
-	     * whenever those numbers change!!!
-	     */
-	    if (records >= 4) {
-		records = (records - 2)/2;
+	    if (records) {
 		lifelog_send_countdown -= records * LIFELOG_TICK;
-		osso_log(LOG_DEBUG, "[%s]:current log has %d entries, adjust send target %d sec closer, remaining %d sec", 
-			 __FUNCTION__, records, records * LIFELOG_TICK, lifelog_send_countdown);
+		osso_log(LOG_DEBUG, "%d lifelog entries, adjust send point closer by %d, %dsec remains",
+			 records, records * LIFELOG_TICK, lifelog_send_countdown);
 		if (lifelog_send_countdown <= 0) {
 		    want_send = TRUE;
 		    lifelog_schedule_try_send();
 		}
 	    }
-
 	} else {
-	    osso_log(LOG_DEBUG, "[%s]:running swver[%s] does not match lifelog file, move file to prev, start a new file", 
-		     __FUNCTION__, lifelog_swrel);
+	    osso_log(LOG_DEBUG, "running swver[%s] does not match lifelog, start a new file", 
+		     lifelog_swrel);
 	    /*
 	     * rename current file tp _prev. If older prev exists, tough luck for it.
 	     */
 	    rename(LIFELOG_FILE, LIFELOG_PREV_FILE);
 	    lifelog_start_new_file();
 	}
+	g_free(curlog);
     }
-    g_free(curlog);
 }
 
 static void
@@ -620,7 +637,7 @@ main(int argc, char *argv[])
 
 	    loop = g_main_loop_new(NULL, FALSE);
 	    osso_hw_set_event_cb(context, &hw_state, hw_state_event_cb, loop);
-	    if (lifelog_enabled && sending_enabled) {
+	    if (lifelog_enabled) {
 		osso_log(LOG_DEBUG, "enable lifelog, snapshot interval %ds, send interval %ds",
 			 LIFELOG_TICK, LIFELOG_SEND_CYCLE);
 		setup_lifelog();
